@@ -28,6 +28,11 @@ from taskflow.tests import utils
 from taskflow.types import failure
 from taskflow.utils import eventlet_utils as eu
 
+try:
+    from taskflow.engines.action_engine import process_executor as pe
+except ImportError:
+    pe = None
+
 
 class FailingRetry(retry.Retry):
 
@@ -1313,6 +1318,7 @@ class ParallelEngineWithEventletTest(RetryTest, test.TestCase):
                                      defer_reverts=defer_reverts)
 
 
+@testtools.skipIf(pe is None, 'process_executor is not available')
 class ParallelEngineWithProcessTest(RetryTest, test.TestCase):
     _EXECUTOR_WORKERS = 2
 
